import React from 'react'
import { createFilterOptions } from '@material-ui/lab/Autocomplete'
import { Contact, ContactOptions } from '../../types'
import { ContactAutocomplete } from './ContactAutocomplete'

type Props = {
  contacts: Contact[]
  contact: ContactOptions
  updateContact: React.Dispatch<React.SetStateAction<{
    name: string;
    phone: string;
  }>>
}

const DEFAULT_INPUT_VALUE = ''

const filter = createFilterOptions<ContactOptions>()

export const ContactAutocompleteByName = ({ contacts, contact, updateContact }: Props) => {
  return (
    <ContactAutocomplete
      contact={contact}
      contacts={contacts}
      getInputValue={(contact) => ({ name: contact.name, phone: DEFAULT_INPUT_VALUE })}
      onChange={(contact: ContactOptions) => {
        if (!contact) {
          return
        }
        if (!contact.isNewContact) {
          updateContact(contact)
        } else if (contact && contact.isNewContact) {
          updateContact((previousContact: Contact) => {
            return {
              ...previousContact,
              name: contact.name
            }
          })
        }
      }}
      filterOptions={(options, params) => {
        const filtered = filter(options, params);
        filtered.push({
          name: params.inputValue,
          phone: '',
          isNewContact: true
        });

        return filtered;
      }}
      label="Name"
    />
  )
}